const fs = require("fs");
const Module = require("./module");

class ModuleManager {
    constructor() {
        console.log("Creating module manager");
        this.moduleList = {};
        this.scanModules();
    }

    scanModules() {
        console.log("Scanning for modules");
        fs.readdirSync(process.env.MODULES_DIR).forEach(file => {
            let rawData = fs.readFileSync(process.env.MODULES_DIR + "/" + file + "/header.json");
            let header = JSON.parse(rawData);

            this.moduleList[header.prefix] = new Module(header.name, 
                header.description, 
                header.prefix, 
                header.flavor, 
                process.env.MODULES_DIR + "/" + file + "/" + header.entrypoint,
                header.version);
        });
    }

    execute(prefix, message) {
        let rawResult = this.moduleList[prefix].run(message);
        let result = JSON.parse(rawResult.toString());

        if(result.status === "success") {
            switch(result.action) {
                case "reply":
                    this.reply(message, result);
                    break;
                case "send":
                    this.send(message, result);
                default:
                    break;
            }
        }
    }

    reply(origin, result) {
        let message = undefined;

        if(result.format === "standard") {
            message = result.message;
        }

        if(result.format === "embed") {
            message = {embed: result.profile}
        }

        origin.reply(message);
    }
}

module.exports = ModuleManager;
